# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class PublishQuestionnaireResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'questionnaire_id': 'str',
        'lc_questionnaire_name': 'str',
        'delete': 'bool',
        'disable': 'bool',
        'draft': 'bool',
        'locales': 'list[PublishQuestionnaireResponseDataLocales]',
        'questionnaire_category': 'list[str]',
        'questionnaire_name': 'str',
        'question_ids': 'list[str]',
        'questionnaire_details': 'PublishQuestionnaireResponseDataQuestionnaireDetails',
        'created_by': 'str',
        'created_by_name': 'str',
        'updated_by': 'str',
        'updated_by_name': 'str',
        'video_screen_interview_id': 'str',
        'date_created': 'int',
        'last_updated': 'int'
    }

    attribute_map = {
        'questionnaire_id': 'questionnaireId',
        'lc_questionnaire_name': 'lcQuestionnaireName',
        'delete': 'delete',
        'disable': 'disable',
        'draft': 'draft',
        'locales': 'locales',
        'questionnaire_category': 'questionnaireCategory',
        'questionnaire_name': 'questionnaireName',
        'question_ids': 'questionIds',
        'questionnaire_details': 'questionnaireDetails',
        'created_by': 'createdBy',
        'created_by_name': 'createdByName',
        'updated_by': 'updatedBy',
        'updated_by_name': 'updatedByName',
        'video_screen_interview_id': 'videoScreenInterviewId',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated'
    }

    def __init__(self, questionnaire_id=None, lc_questionnaire_name=None, delete=None, disable=None, draft=None, locales=None, questionnaire_category=None, questionnaire_name=None, question_ids=None, questionnaire_details=None, created_by=None, created_by_name=None, updated_by=None, updated_by_name=None, video_screen_interview_id=None, date_created=None, last_updated=None):  # noqa: E501
        """PublishQuestionnaireResponseData - a model defined in Swagger"""  # noqa: E501
        self._questionnaire_id = None
        self._lc_questionnaire_name = None
        self._delete = None
        self._disable = None
        self._draft = None
        self._locales = None
        self._questionnaire_category = None
        self._questionnaire_name = None
        self._question_ids = None
        self._questionnaire_details = None
        self._created_by = None
        self._created_by_name = None
        self._updated_by = None
        self._updated_by_name = None
        self._video_screen_interview_id = None
        self._date_created = None
        self._last_updated = None
        self.discriminator = None
        self.questionnaire_id = questionnaire_id
        self.lc_questionnaire_name = lc_questionnaire_name
        self.delete = delete
        self.disable = disable
        self.draft = draft
        self.locales = locales
        if questionnaire_category is not None:
            self.questionnaire_category = questionnaire_category
        self.questionnaire_name = questionnaire_name
        self.question_ids = question_ids
        self.questionnaire_details = questionnaire_details
        self.created_by = created_by
        self.created_by_name = created_by_name
        self.updated_by = updated_by
        self.updated_by_name = updated_by_name
        self.video_screen_interview_id = video_screen_interview_id
        self.date_created = date_created
        self.last_updated = last_updated

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this PublishQuestionnaireResponseData.  # noqa: E501

        QuestionnaireId for the questionnaire.  # noqa: E501

        :return: The questionnaire_id of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this PublishQuestionnaireResponseData.

        QuestionnaireId for the questionnaire.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if questionnaire_id is None:
            raise ValueError("Invalid value for `questionnaire_id`, must not be `None`")  # noqa: E501

        self._questionnaire_id = questionnaire_id

    @property
    def lc_questionnaire_name(self):
        """Gets the lc_questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501

        Questionnaire name in lower case.  # noqa: E501

        :return: The lc_questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._lc_questionnaire_name

    @lc_questionnaire_name.setter
    def lc_questionnaire_name(self, lc_questionnaire_name):
        """Sets the lc_questionnaire_name of this PublishQuestionnaireResponseData.

        Questionnaire name in lower case.  # noqa: E501

        :param lc_questionnaire_name: The lc_questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if lc_questionnaire_name is None:
            raise ValueError("Invalid value for `lc_questionnaire_name`, must not be `None`")  # noqa: E501

        self._lc_questionnaire_name = lc_questionnaire_name

    @property
    def delete(self):
        """Gets the delete of this PublishQuestionnaireResponseData.  # noqa: E501

        True if questionnaire deleted. Else false.  # noqa: E501

        :return: The delete of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this PublishQuestionnaireResponseData.

        True if questionnaire deleted. Else false.  # noqa: E501

        :param delete: The delete of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: bool
        """
        if delete is None:
            raise ValueError("Invalid value for `delete`, must not be `None`")  # noqa: E501

        self._delete = delete

    @property
    def disable(self):
        """Gets the disable of this PublishQuestionnaireResponseData.  # noqa: E501

        True if questionnaire disabled. Else false.  # noqa: E501

        :return: The disable of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._disable

    @disable.setter
    def disable(self, disable):
        """Sets the disable of this PublishQuestionnaireResponseData.

        True if questionnaire disabled. Else false.  # noqa: E501

        :param disable: The disable of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: bool
        """
        if disable is None:
            raise ValueError("Invalid value for `disable`, must not be `None`")  # noqa: E501

        self._disable = disable

    @property
    def draft(self):
        """Gets the draft of this PublishQuestionnaireResponseData.  # noqa: E501

        True if questionnaire is in draft. Else false.  # noqa: E501

        :return: The draft of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """Sets the draft of this PublishQuestionnaireResponseData.

        True if questionnaire is in draft. Else false.  # noqa: E501

        :param draft: The draft of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: bool
        """
        if draft is None:
            raise ValueError("Invalid value for `draft`, must not be `None`")  # noqa: E501

        self._draft = draft

    @property
    def locales(self):
        """Gets the locales of this PublishQuestionnaireResponseData.  # noqa: E501

        Locales applicable for questions to be translated.  # noqa: E501

        :return: The locales of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: list[PublishQuestionnaireResponseDataLocales]
        """
        return self._locales

    @locales.setter
    def locales(self, locales):
        """Sets the locales of this PublishQuestionnaireResponseData.

        Locales applicable for questions to be translated.  # noqa: E501

        :param locales: The locales of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: list[PublishQuestionnaireResponseDataLocales]
        """
        if locales is None:
            raise ValueError("Invalid value for `locales`, must not be `None`")  # noqa: E501

        self._locales = locales

    @property
    def questionnaire_category(self):
        """Gets the questionnaire_category of this PublishQuestionnaireResponseData.  # noqa: E501

        Indicates the categories this questionnaire belongs to.  # noqa: E501

        :return: The questionnaire_category of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: list[str]
        """
        return self._questionnaire_category

    @questionnaire_category.setter
    def questionnaire_category(self, questionnaire_category):
        """Sets the questionnaire_category of this PublishQuestionnaireResponseData.

        Indicates the categories this questionnaire belongs to.  # noqa: E501

        :param questionnaire_category: The questionnaire_category of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: list[str]
        """

        self._questionnaire_category = questionnaire_category

    @property
    def questionnaire_name(self):
        """Gets the questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501

        Questionnaire name while created.  # noqa: E501

        :return: The questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_name

    @questionnaire_name.setter
    def questionnaire_name(self, questionnaire_name):
        """Sets the questionnaire_name of this PublishQuestionnaireResponseData.

        Questionnaire name while created.  # noqa: E501

        :param questionnaire_name: The questionnaire_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if questionnaire_name is None:
            raise ValueError("Invalid value for `questionnaire_name`, must not be `None`")  # noqa: E501

        self._questionnaire_name = questionnaire_name

    @property
    def question_ids(self):
        """Gets the question_ids of this PublishQuestionnaireResponseData.  # noqa: E501


        :return: The question_ids of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: list[str]
        """
        return self._question_ids

    @question_ids.setter
    def question_ids(self, question_ids):
        """Sets the question_ids of this PublishQuestionnaireResponseData.


        :param question_ids: The question_ids of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: list[str]
        """
        if question_ids is None:
            raise ValueError("Invalid value for `question_ids`, must not be `None`")  # noqa: E501

        self._question_ids = question_ids

    @property
    def questionnaire_details(self):
        """Gets the questionnaire_details of this PublishQuestionnaireResponseData.  # noqa: E501


        :return: The questionnaire_details of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: PublishQuestionnaireResponseDataQuestionnaireDetails
        """
        return self._questionnaire_details

    @questionnaire_details.setter
    def questionnaire_details(self, questionnaire_details):
        """Sets the questionnaire_details of this PublishQuestionnaireResponseData.


        :param questionnaire_details: The questionnaire_details of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: PublishQuestionnaireResponseDataQuestionnaireDetails
        """
        if questionnaire_details is None:
            raise ValueError("Invalid value for `questionnaire_details`, must not be `None`")  # noqa: E501

        self._questionnaire_details = questionnaire_details

    @property
    def created_by(self):
        """Gets the created_by of this PublishQuestionnaireResponseData.  # noqa: E501

        Id of the recruiter who created questionnaire.  # noqa: E501

        :return: The created_by of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PublishQuestionnaireResponseData.

        Id of the recruiter who created questionnaire.  # noqa: E501

        :param created_by: The created_by of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_by_name(self):
        """Gets the created_by_name of this PublishQuestionnaireResponseData.  # noqa: E501

        Name of the recruiter who created questionnaire.  # noqa: E501

        :return: The created_by_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_name

    @created_by_name.setter
    def created_by_name(self, created_by_name):
        """Sets the created_by_name of this PublishQuestionnaireResponseData.

        Name of the recruiter who created questionnaire.  # noqa: E501

        :param created_by_name: The created_by_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if created_by_name is None:
            raise ValueError("Invalid value for `created_by_name`, must not be `None`")  # noqa: E501

        self._created_by_name = created_by_name

    @property
    def updated_by(self):
        """Gets the updated_by of this PublishQuestionnaireResponseData.  # noqa: E501

        Id of the recruiter who updated questionnaire.  # noqa: E501

        :return: The updated_by of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this PublishQuestionnaireResponseData.

        Id of the recruiter who updated questionnaire.  # noqa: E501

        :param updated_by: The updated_by of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if updated_by is None:
            raise ValueError("Invalid value for `updated_by`, must not be `None`")  # noqa: E501

        self._updated_by = updated_by

    @property
    def updated_by_name(self):
        """Gets the updated_by_name of this PublishQuestionnaireResponseData.  # noqa: E501

        Name of the recruiter who updated questionnaire.  # noqa: E501

        :return: The updated_by_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_by_name

    @updated_by_name.setter
    def updated_by_name(self, updated_by_name):
        """Sets the updated_by_name of this PublishQuestionnaireResponseData.

        Name of the recruiter who updated questionnaire.  # noqa: E501

        :param updated_by_name: The updated_by_name of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if updated_by_name is None:
            raise ValueError("Invalid value for `updated_by_name`, must not be `None`")  # noqa: E501

        self._updated_by_name = updated_by_name

    @property
    def video_screen_interview_id(self):
        """Gets the video_screen_interview_id of this PublishQuestionnaireResponseData.  # noqa: E501

        Questionnaire interview id associated when questionnaire is created or updated.  # noqa: E501

        :return: The video_screen_interview_id of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_interview_id

    @video_screen_interview_id.setter
    def video_screen_interview_id(self, video_screen_interview_id):
        """Sets the video_screen_interview_id of this PublishQuestionnaireResponseData.

        Questionnaire interview id associated when questionnaire is created or updated.  # noqa: E501

        :param video_screen_interview_id: The video_screen_interview_id of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: str
        """
        if video_screen_interview_id is None:
            raise ValueError("Invalid value for `video_screen_interview_id`, must not be `None`")  # noqa: E501

        self._video_screen_interview_id = video_screen_interview_id

    @property
    def date_created(self):
        """Gets the date_created of this PublishQuestionnaireResponseData.  # noqa: E501

        Date when questionnaire is created.  # noqa: E501

        :return: The date_created of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PublishQuestionnaireResponseData.

        Date when questionnaire is created.  # noqa: E501

        :param date_created: The date_created of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this PublishQuestionnaireResponseData.  # noqa: E501

        Date when questionnaire is updated.  # noqa: E501

        :return: The last_updated of this PublishQuestionnaireResponseData.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this PublishQuestionnaireResponseData.

        Date when questionnaire is updated.  # noqa: E501

        :param last_updated: The last_updated of this PublishQuestionnaireResponseData.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PublishQuestionnaireResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublishQuestionnaireResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateProjectRequestProjectAttachmentList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_name': 'str',
        'description': 'str',
        'file_url': 'str',
        'uploaded_by_email': 'str',
        'uploaded_by_name': 'str',
        'size': 'int'
    }

    attribute_map = {
        'file_name': 'fileName',
        'description': 'description',
        'file_url': 'fileUrl',
        'uploaded_by_email': 'uploadedByEmail',
        'uploaded_by_name': 'uploadedByName',
        'size': 'size'
    }

    def __init__(self, file_name=None, description=None, file_url=None, uploaded_by_email=None, uploaded_by_name=None, size=None):  # noqa: E501
        """CreateProjectRequestProjectAttachmentList - a model defined in Swagger"""  # noqa: E501
        self._file_name = None
        self._description = None
        self._file_url = None
        self._uploaded_by_email = None
        self._uploaded_by_name = None
        self._size = None
        self.discriminator = None
        self.file_name = file_name
        self.description = description
        self.file_url = file_url
        self.uploaded_by_email = uploaded_by_email
        self.uploaded_by_name = uploaded_by_name
        self.size = size

    @property
    def file_name(self):
        """Gets the file_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        Name of the attached file.  # noqa: E501

        :return: The file_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this CreateProjectRequestProjectAttachmentList.

        Name of the attached file.  # noqa: E501

        :param file_name: The file_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    @property
    def description(self):
        """Gets the description of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        Description of the attached file.  # noqa: E501

        :return: The description of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateProjectRequestProjectAttachmentList.

        Description of the attached file.  # noqa: E501

        :param description: The description of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def file_url(self):
        """Gets the file_url of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        URL of the attached file.  # noqa: E501

        :return: The file_url of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._file_url

    @file_url.setter
    def file_url(self, file_url):
        """Sets the file_url of this CreateProjectRequestProjectAttachmentList.

        URL of the attached file.  # noqa: E501

        :param file_url: The file_url of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: str
        """
        if file_url is None:
            raise ValueError("Invalid value for `file_url`, must not be `None`")  # noqa: E501

        self._file_url = file_url

    @property
    def uploaded_by_email(self):
        """Gets the uploaded_by_email of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        Email of the user who uploaded the file.  # noqa: E501

        :return: The uploaded_by_email of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._uploaded_by_email

    @uploaded_by_email.setter
    def uploaded_by_email(self, uploaded_by_email):
        """Sets the uploaded_by_email of this CreateProjectRequestProjectAttachmentList.

        Email of the user who uploaded the file.  # noqa: E501

        :param uploaded_by_email: The uploaded_by_email of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: str
        """
        if uploaded_by_email is None:
            raise ValueError("Invalid value for `uploaded_by_email`, must not be `None`")  # noqa: E501

        self._uploaded_by_email = uploaded_by_email

    @property
    def uploaded_by_name(self):
        """Gets the uploaded_by_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        Name of the user who uploaded the file.  # noqa: E501

        :return: The uploaded_by_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: str
        """
        return self._uploaded_by_name

    @uploaded_by_name.setter
    def uploaded_by_name(self, uploaded_by_name):
        """Sets the uploaded_by_name of this CreateProjectRequestProjectAttachmentList.

        Name of the user who uploaded the file.  # noqa: E501

        :param uploaded_by_name: The uploaded_by_name of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: str
        """
        if uploaded_by_name is None:
            raise ValueError("Invalid value for `uploaded_by_name`, must not be `None`")  # noqa: E501

        self._uploaded_by_name = uploaded_by_name

    @property
    def size(self):
        """Gets the size of this CreateProjectRequestProjectAttachmentList.  # noqa: E501

        Size of the attached file in bytes.  # noqa: E501

        :return: The size of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this CreateProjectRequestProjectAttachmentList.

        Size of the attached file in bytes.  # noqa: E501

        :param size: The size of this CreateProjectRequestProjectAttachmentList.  # noqa: E501
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateProjectRequestProjectAttachmentList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateProjectRequestProjectAttachmentList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedataExperiencesummary(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currentemployer': 'str',
        'currentrole': 'str',
        'gapperiod': 'str',
        'longeststay': 'str',
        'averagestay': 'str',
        'totalexperienceinmonths': 'str',
        'totalexperienceinyear': 'str'
    }

    attribute_map = {
        'currentemployer': 'currentemployer',
        'currentrole': 'currentrole',
        'gapperiod': 'gapperiod',
        'longeststay': 'longeststay',
        'averagestay': 'averagestay',
        'totalexperienceinmonths': 'totalexperienceinmonths',
        'totalexperienceinyear': 'totalexperienceinyear'
    }

    def __init__(self, currentemployer=None, currentrole=None, gapperiod=None, longeststay=None, averagestay=None, totalexperienceinmonths=None, totalexperienceinyear=None):  # noqa: E501
        """ResumeResponseDataResumedataExperiencesummary - a model defined in Swagger"""  # noqa: E501
        self._currentemployer = None
        self._currentrole = None
        self._gapperiod = None
        self._longeststay = None
        self._averagestay = None
        self._totalexperienceinmonths = None
        self._totalexperienceinyear = None
        self.discriminator = None
        if currentemployer is not None:
            self.currentemployer = currentemployer
        if currentrole is not None:
            self.currentrole = currentrole
        if gapperiod is not None:
            self.gapperiod = gapperiod
        if longeststay is not None:
            self.longeststay = longeststay
        if averagestay is not None:
            self.averagestay = averagestay
        if totalexperienceinmonths is not None:
            self.totalexperienceinmonths = totalexperienceinmonths
        if totalexperienceinyear is not None:
            self.totalexperienceinyear = totalexperienceinyear

    @property
    def currentemployer(self):
        """Gets the currentemployer of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Candidate working in current Company.  # noqa: E501

        :return: The currentemployer of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._currentemployer

    @currentemployer.setter
    def currentemployer(self, currentemployer):
        """Sets the currentemployer of this ResumeResponseDataResumedataExperiencesummary.

        Candidate working in current Company.  # noqa: E501

        :param currentemployer: The currentemployer of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._currentemployer = currentemployer

    @property
    def currentrole(self):
        """Gets the currentrole of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Current role of candidate.  # noqa: E501

        :return: The currentrole of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._currentrole

    @currentrole.setter
    def currentrole(self, currentrole):
        """Sets the currentrole of this ResumeResponseDataResumedataExperiencesummary.

        Current role of candidate.  # noqa: E501

        :param currentrole: The currentrole of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._currentrole = currentrole

    @property
    def gapperiod(self):
        """Gets the gapperiod of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Time frame for which candidate is not working.  # noqa: E501

        :return: The gapperiod of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._gapperiod

    @gapperiod.setter
    def gapperiod(self, gapperiod):
        """Sets the gapperiod of this ResumeResponseDataResumedataExperiencesummary.

        Time frame for which candidate is not working.  # noqa: E501

        :param gapperiod: The gapperiod of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._gapperiod = gapperiod

    @property
    def longeststay(self):
        """Gets the longeststay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Longest time frame in a Company.  # noqa: E501

        :return: The longeststay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._longeststay

    @longeststay.setter
    def longeststay(self, longeststay):
        """Sets the longeststay of this ResumeResponseDataResumedataExperiencesummary.

        Longest time frame in a Company.  # noqa: E501

        :param longeststay: The longeststay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._longeststay = longeststay

    @property
    def averagestay(self):
        """Gets the averagestay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Average stay.  # noqa: E501

        :return: The averagestay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._averagestay

    @averagestay.setter
    def averagestay(self, averagestay):
        """Sets the averagestay of this ResumeResponseDataResumedataExperiencesummary.

        Average stay.  # noqa: E501

        :param averagestay: The averagestay of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._averagestay = averagestay

    @property
    def totalexperienceinmonths(self):
        """Gets the totalexperienceinmonths of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Total experience in months.  # noqa: E501

        :return: The totalexperienceinmonths of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._totalexperienceinmonths

    @totalexperienceinmonths.setter
    def totalexperienceinmonths(self, totalexperienceinmonths):
        """Sets the totalexperienceinmonths of this ResumeResponseDataResumedataExperiencesummary.

        Total experience in months.  # noqa: E501

        :param totalexperienceinmonths: The totalexperienceinmonths of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._totalexperienceinmonths = totalexperienceinmonths

    @property
    def totalexperienceinyear(self):
        """Gets the totalexperienceinyear of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501

        Total experience in year.  # noqa: E501

        :return: The totalexperienceinyear of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :rtype: str
        """
        return self._totalexperienceinyear

    @totalexperienceinyear.setter
    def totalexperienceinyear(self, totalexperienceinyear):
        """Sets the totalexperienceinyear of this ResumeResponseDataResumedataExperiencesummary.

        Total experience in year.  # noqa: E501

        :param totalexperienceinyear: The totalexperienceinyear of this ResumeResponseDataResumedataExperiencesummary.  # noqa: E501
        :type: str
        """

        self._totalexperienceinyear = totalexperienceinyear

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedataExperiencesummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedataExperiencesummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SearchResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'user_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'realm': 'str',
        'email': 'str',
        'user_desc': 'str',
        'enabled': 'bool',
        'user_type': 'str',
        'legacy_user_id': 'str',
        'is_email_verified': 'bool',
        'created_on': 'float',
        'app_access_count': 'float',
        'group_count': 'float',
        'configure_otp': 'bool',
        'org_name': 'str'
    }

    attribute_map = {
        'id': 'id',
        'user_name': 'userName',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'realm': 'realm',
        'email': 'email',
        'user_desc': 'userDesc',
        'enabled': 'enabled',
        'user_type': 'userType',
        'legacy_user_id': 'legacyUserId',
        'is_email_verified': 'isEmailVerified',
        'created_on': 'createdOn',
        'app_access_count': 'appAccessCount',
        'group_count': 'groupCount',
        'configure_otp': 'configureOtp',
        'org_name': 'orgName'
    }

    def __init__(self, id=None, user_name=None, first_name=None, last_name=None, realm=None, email=None, user_desc=None, enabled=None, user_type=None, legacy_user_id=None, is_email_verified=None, created_on=None, app_access_count=None, group_count=None, configure_otp=None, org_name=None):  # noqa: E501
        """SearchResponseData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._user_name = None
        self._first_name = None
        self._last_name = None
        self._realm = None
        self._email = None
        self._user_desc = None
        self._enabled = None
        self._user_type = None
        self._legacy_user_id = None
        self._is_email_verified = None
        self._created_on = None
        self._app_access_count = None
        self._group_count = None
        self._configure_otp = None
        self._org_name = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if user_name is not None:
            self.user_name = user_name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if realm is not None:
            self.realm = realm
        if email is not None:
            self.email = email
        if user_desc is not None:
            self.user_desc = user_desc
        if enabled is not None:
            self.enabled = enabled
        if user_type is not None:
            self.user_type = user_type
        if legacy_user_id is not None:
            self.legacy_user_id = legacy_user_id
        if is_email_verified is not None:
            self.is_email_verified = is_email_verified
        if created_on is not None:
            self.created_on = created_on
        if app_access_count is not None:
            self.app_access_count = app_access_count
        if group_count is not None:
            self.group_count = group_count
        if configure_otp is not None:
            self.configure_otp = configure_otp
        if org_name is not None:
            self.org_name = org_name

    @property
    def id(self):
        """Gets the id of this SearchResponseData.  # noqa: E501

        ID of the user.  # noqa: E501

        :return: The id of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SearchResponseData.

        ID of the user.  # noqa: E501

        :param id: The id of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def user_name(self):
        """Gets the user_name of this SearchResponseData.  # noqa: E501

        Username of the user.  # noqa: E501

        :return: The user_name of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this SearchResponseData.

        Username of the user.  # noqa: E501

        :param user_name: The user_name of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def first_name(self):
        """Gets the first_name of this SearchResponseData.  # noqa: E501

        First name of the user.  # noqa: E501

        :return: The first_name of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this SearchResponseData.

        First name of the user.  # noqa: E501

        :param first_name: The first_name of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this SearchResponseData.  # noqa: E501

        Last name of the user.  # noqa: E501

        :return: The last_name of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this SearchResponseData.

        Last name of the user.  # noqa: E501

        :param last_name: The last_name of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def realm(self):
        """Gets the realm of this SearchResponseData.  # noqa: E501

        Realm of the user.  # noqa: E501

        :return: The realm of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._realm

    @realm.setter
    def realm(self, realm):
        """Sets the realm of this SearchResponseData.

        Realm of the user.  # noqa: E501

        :param realm: The realm of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._realm = realm

    @property
    def email(self):
        """Gets the email of this SearchResponseData.  # noqa: E501

        Email address of the user.  # noqa: E501

        :return: The email of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this SearchResponseData.

        Email address of the user.  # noqa: E501

        :param email: The email of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def user_desc(self):
        """Gets the user_desc of this SearchResponseData.  # noqa: E501

        Description of the user.  # noqa: E501

        :return: The user_desc of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._user_desc

    @user_desc.setter
    def user_desc(self, user_desc):
        """Sets the user_desc of this SearchResponseData.

        Description of the user.  # noqa: E501

        :param user_desc: The user_desc of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._user_desc = user_desc

    @property
    def enabled(self):
        """Gets the enabled of this SearchResponseData.  # noqa: E501

        Flag indicating if the user is enabled.  # noqa: E501

        :return: The enabled of this SearchResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this SearchResponseData.

        Flag indicating if the user is enabled.  # noqa: E501

        :param enabled: The enabled of this SearchResponseData.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def user_type(self):
        """Gets the user_type of this SearchResponseData.  # noqa: E501

        Type of the user.  # noqa: E501

        :return: The user_type of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this SearchResponseData.

        Type of the user.  # noqa: E501

        :param user_type: The user_type of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def legacy_user_id(self):
        """Gets the legacy_user_id of this SearchResponseData.  # noqa: E501

        Legacy ID of the user.  # noqa: E501

        :return: The legacy_user_id of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._legacy_user_id

    @legacy_user_id.setter
    def legacy_user_id(self, legacy_user_id):
        """Sets the legacy_user_id of this SearchResponseData.

        Legacy ID of the user.  # noqa: E501

        :param legacy_user_id: The legacy_user_id of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._legacy_user_id = legacy_user_id

    @property
    def is_email_verified(self):
        """Gets the is_email_verified of this SearchResponseData.  # noqa: E501

        Flag indicating if the user's email is verified.  # noqa: E501

        :return: The is_email_verified of this SearchResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._is_email_verified

    @is_email_verified.setter
    def is_email_verified(self, is_email_verified):
        """Sets the is_email_verified of this SearchResponseData.

        Flag indicating if the user's email is verified.  # noqa: E501

        :param is_email_verified: The is_email_verified of this SearchResponseData.  # noqa: E501
        :type: bool
        """

        self._is_email_verified = is_email_verified

    @property
    def created_on(self):
        """Gets the created_on of this SearchResponseData.  # noqa: E501

        Timestamp indicating when the user was created.  # noqa: E501

        :return: The created_on of this SearchResponseData.  # noqa: E501
        :rtype: float
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SearchResponseData.

        Timestamp indicating when the user was created.  # noqa: E501

        :param created_on: The created_on of this SearchResponseData.  # noqa: E501
        :type: float
        """

        self._created_on = created_on

    @property
    def app_access_count(self):
        """Gets the app_access_count of this SearchResponseData.  # noqa: E501

        Count of applications the user has access to.  # noqa: E501

        :return: The app_access_count of this SearchResponseData.  # noqa: E501
        :rtype: float
        """
        return self._app_access_count

    @app_access_count.setter
    def app_access_count(self, app_access_count):
        """Sets the app_access_count of this SearchResponseData.

        Count of applications the user has access to.  # noqa: E501

        :param app_access_count: The app_access_count of this SearchResponseData.  # noqa: E501
        :type: float
        """

        self._app_access_count = app_access_count

    @property
    def group_count(self):
        """Gets the group_count of this SearchResponseData.  # noqa: E501

        Count of groups the user is a part of.  # noqa: E501

        :return: The group_count of this SearchResponseData.  # noqa: E501
        :rtype: float
        """
        return self._group_count

    @group_count.setter
    def group_count(self, group_count):
        """Sets the group_count of this SearchResponseData.

        Count of groups the user is a part of.  # noqa: E501

        :param group_count: The group_count of this SearchResponseData.  # noqa: E501
        :type: float
        """

        self._group_count = group_count

    @property
    def configure_otp(self):
        """Gets the configure_otp of this SearchResponseData.  # noqa: E501

        Flag indicating if OTP is configured for the user.  # noqa: E501

        :return: The configure_otp of this SearchResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._configure_otp

    @configure_otp.setter
    def configure_otp(self, configure_otp):
        """Sets the configure_otp of this SearchResponseData.

        Flag indicating if OTP is configured for the user.  # noqa: E501

        :param configure_otp: The configure_otp of this SearchResponseData.  # noqa: E501
        :type: bool
        """

        self._configure_otp = configure_otp

    @property
    def org_name(self):
        """Gets the org_name of this SearchResponseData.  # noqa: E501

        Name of the organization associated with the user.  # noqa: E501

        :return: The org_name of this SearchResponseData.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this SearchResponseData.

        Name of the organization associated with the user.  # noqa: E501

        :param org_name: The org_name of this SearchResponseData.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ex-search-api

    These APIs helps in searching and providing suggestions based on keywords within employee profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class TabInfoNode(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'type': 'str',
        'mutual_history': 'bool'
    }

    attribute_map = {
        'key': 'key',
        'type': 'type',
        'mutual_history': 'mutualHistory'
    }

    def __init__(self, key=None, type=None, mutual_history=None):  # noqa: E501
        """TabInfoNode - a model defined in Swagger"""  # noqa: E501
        self._key = None
        self._type = None
        self._mutual_history = None
        self.discriminator = None
        if key is not None:
            self.key = key
        if type is not None:
            self.type = type
        if mutual_history is not None:
            self.mutual_history = mutual_history

    @property
    def key(self):
        """Gets the key of this TabInfoNode.  # noqa: E501

        Field name to populate fields based on this attribute.  # noqa: E501

        :return: The key of this TabInfoNode.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TabInfoNode.

        Field name to populate fields based on this attribute.  # noqa: E501

        :param key: The key of this TabInfoNode.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def type(self):
        """Gets the type of this TabInfoNode.  # noqa: E501

        Accepted Value - Custom.  # noqa: E501

        :return: The type of this TabInfoNode.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this TabInfoNode.

        Accepted Value - Custom.  # noqa: E501

        :param type: The type of this TabInfoNode.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def mutual_history(self):
        """Gets the mutual_history of this TabInfoNode.  # noqa: E501

        True or False based on Profiles Settings.  # noqa: E501

        :return: The mutual_history of this TabInfoNode.  # noqa: E501
        :rtype: bool
        """
        return self._mutual_history

    @mutual_history.setter
    def mutual_history(self, mutual_history):
        """Sets the mutual_history of this TabInfoNode.

        True or False based on Profiles Settings.  # noqa: E501

        :param mutual_history: The mutual_history of this TabInfoNode.  # noqa: E501
        :type: bool
        """

        self._mutual_history = mutual_history

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TabInfoNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TabInfoNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Links(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_self': 'str',
        'prev': 'str',
        'next': 'str'
    }

    attribute_map = {
        '_self': 'self',
        'prev': 'prev',
        'next': 'next'
    }

    def __init__(self, _self=None, prev=None, next=None):  # noqa: E501
        """Links - a model defined in Swagger"""  # noqa: E501
        self.__self = None
        self._prev = None
        self._next = None
        self.discriminator = None
        if _self is not None:
            self._self = _self
        if prev is not None:
            self.prev = prev
        if next is not None:
            self.next = next

    @property
    def _self(self):
        """Gets the _self of this Links.  # noqa: E501

        The link to the current page.  # noqa: E501

        :return: The _self of this Links.  # noqa: E501
        :rtype: str
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """Sets the _self of this Links.

        The link to the current page.  # noqa: E501

        :param _self: The _self of this Links.  # noqa: E501
        :type: str
        """

        self.__self = _self

    @property
    def prev(self):
        """Gets the prev of this Links.  # noqa: E501

        The link to the previous page.  # noqa: E501

        :return: The prev of this Links.  # noqa: E501
        :rtype: str
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """Sets the prev of this Links.

        The link to the previous page.  # noqa: E501

        :param prev: The prev of this Links.  # noqa: E501
        :type: str
        """

        self._prev = prev

    @property
    def next(self):
        """Gets the next of this Links.  # noqa: E501

        The link to the next page.  # noqa: E501

        :return: The next of this Links.  # noqa: E501
        :rtype: str
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this Links.

        The link to the next page.  # noqa: E501

        :param next: The next of this Links.  # noqa: E501
        :type: str
        """

        self._next = next

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Links, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Links):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    communications-sms

    These APIs ensures an easy integration process of SMS management for developers to send, read, and track SMS histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SMSHistoryPagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first': 'bool',
        'last': 'bool',
        'has_errors': 'bool',
        'has_next': 'bool',
        'total_elements': 'int',
        'total_pages': 'int',
        'size': 'int',
        'current_page': 'int',
        'number_of_elements': 'int'
    }

    attribute_map = {
        'first': 'first',
        'last': 'last',
        'has_errors': 'hasErrors',
        'has_next': 'hasNext',
        'total_elements': 'totalElements',
        'total_pages': 'totalPages',
        'size': 'size',
        'current_page': 'currentPage',
        'number_of_elements': 'numberOfElements'
    }

    def __init__(self, first=None, last=None, has_errors=None, has_next=None, total_elements=None, total_pages=None, size=None, current_page=None, number_of_elements=None):  # noqa: E501
        """SMSHistoryPagination - a model defined in Swagger"""  # noqa: E501
        self._first = None
        self._last = None
        self._has_errors = None
        self._has_next = None
        self._total_elements = None
        self._total_pages = None
        self._size = None
        self._current_page = None
        self._number_of_elements = None
        self.discriminator = None
        self.first = first
        self.last = last
        self.has_errors = has_errors
        self.has_next = has_next
        self.total_elements = total_elements
        self.total_pages = total_pages
        self.size = size
        self.current_page = current_page
        self.number_of_elements = number_of_elements

    @property
    def first(self):
        """Gets the first of this SMSHistoryPagination.  # noqa: E501

        Indicates the first page in the pagination.  # noqa: E501

        :return: The first of this SMSHistoryPagination.  # noqa: E501
        :rtype: bool
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this SMSHistoryPagination.

        Indicates the first page in the pagination.  # noqa: E501

        :param first: The first of this SMSHistoryPagination.  # noqa: E501
        :type: bool
        """
        if first is None:
            raise ValueError("Invalid value for `first`, must not be `None`")  # noqa: E501

        self._first = first

    @property
    def last(self):
        """Gets the last of this SMSHistoryPagination.  # noqa: E501

        Indicates last page in the pagination.  # noqa: E501

        :return: The last of this SMSHistoryPagination.  # noqa: E501
        :rtype: bool
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this SMSHistoryPagination.

        Indicates last page in the pagination.  # noqa: E501

        :param last: The last of this SMSHistoryPagination.  # noqa: E501
        :type: bool
        """
        if last is None:
            raise ValueError("Invalid value for `last`, must not be `None`")  # noqa: E501

        self._last = last

    @property
    def has_errors(self):
        """Gets the has_errors of this SMSHistoryPagination.  # noqa: E501

        Indicates whether there are errors in the pagination.  # noqa: E501

        :return: The has_errors of this SMSHistoryPagination.  # noqa: E501
        :rtype: bool
        """
        return self._has_errors

    @has_errors.setter
    def has_errors(self, has_errors):
        """Sets the has_errors of this SMSHistoryPagination.

        Indicates whether there are errors in the pagination.  # noqa: E501

        :param has_errors: The has_errors of this SMSHistoryPagination.  # noqa: E501
        :type: bool
        """
        if has_errors is None:
            raise ValueError("Invalid value for `has_errors`, must not be `None`")  # noqa: E501

        self._has_errors = has_errors

    @property
    def has_next(self):
        """Gets the has_next of this SMSHistoryPagination.  # noqa: E501

        Indicates whether there is a next page in the pagination.  # noqa: E501

        :return: The has_next of this SMSHistoryPagination.  # noqa: E501
        :rtype: bool
        """
        return self._has_next

    @has_next.setter
    def has_next(self, has_next):
        """Sets the has_next of this SMSHistoryPagination.

        Indicates whether there is a next page in the pagination.  # noqa: E501

        :param has_next: The has_next of this SMSHistoryPagination.  # noqa: E501
        :type: bool
        """
        if has_next is None:
            raise ValueError("Invalid value for `has_next`, must not be `None`")  # noqa: E501

        self._has_next = has_next

    @property
    def total_elements(self):
        """Gets the total_elements of this SMSHistoryPagination.  # noqa: E501

        Total number of elements across all pages.  # noqa: E501

        :return: The total_elements of this SMSHistoryPagination.  # noqa: E501
        :rtype: int
        """
        return self._total_elements

    @total_elements.setter
    def total_elements(self, total_elements):
        """Sets the total_elements of this SMSHistoryPagination.

        Total number of elements across all pages.  # noqa: E501

        :param total_elements: The total_elements of this SMSHistoryPagination.  # noqa: E501
        :type: int
        """
        if total_elements is None:
            raise ValueError("Invalid value for `total_elements`, must not be `None`")  # noqa: E501

        self._total_elements = total_elements

    @property
    def total_pages(self):
        """Gets the total_pages of this SMSHistoryPagination.  # noqa: E501

        Total number of pages in the pagination.  # noqa: E501

        :return: The total_pages of this SMSHistoryPagination.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this SMSHistoryPagination.

        Total number of pages in the pagination.  # noqa: E501

        :param total_pages: The total_pages of this SMSHistoryPagination.  # noqa: E501
        :type: int
        """
        if total_pages is None:
            raise ValueError("Invalid value for `total_pages`, must not be `None`")  # noqa: E501

        self._total_pages = total_pages

    @property
    def size(self):
        """Gets the size of this SMSHistoryPagination.  # noqa: E501

        Number of elements in the current page.  # noqa: E501

        :return: The size of this SMSHistoryPagination.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SMSHistoryPagination.

        Number of elements in the current page.  # noqa: E501

        :param size: The size of this SMSHistoryPagination.  # noqa: E501
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def current_page(self):
        """Gets the current_page of this SMSHistoryPagination.  # noqa: E501

        The current page number.  # noqa: E501

        :return: The current_page of this SMSHistoryPagination.  # noqa: E501
        :rtype: int
        """
        return self._current_page

    @current_page.setter
    def current_page(self, current_page):
        """Sets the current_page of this SMSHistoryPagination.

        The current page number.  # noqa: E501

        :param current_page: The current_page of this SMSHistoryPagination.  # noqa: E501
        :type: int
        """
        if current_page is None:
            raise ValueError("Invalid value for `current_page`, must not be `None`")  # noqa: E501

        self._current_page = current_page

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this SMSHistoryPagination.  # noqa: E501

        Number of elements in the current page.  # noqa: E501

        :return: The number_of_elements of this SMSHistoryPagination.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this SMSHistoryPagination.

        Number of elements in the current page.  # noqa: E501

        :param number_of_elements: The number_of_elements of this SMSHistoryPagination.  # noqa: E501
        :type: int
        """
        if number_of_elements is None:
            raise ValueError("Invalid value for `number_of_elements`, must not be `None`")  # noqa: E501

        self._number_of_elements = number_of_elements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SMSHistoryPagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SMSHistoryPagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsAssigned(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'assigned_to_name': 'str',
        'source': 'str',
        'assigned_by': 'float',
        'assigned_to_email': 'str',
        'user_type': 'str',
        'assigned_to': 'str'
    }

    attribute_map = {
        'assigned_to_name': 'assignedToName',
        'source': 'source',
        'assigned_by': 'assignedBy',
        'assigned_to_email': 'assignedToEmail',
        'user_type': 'userType',
        'assigned_to': 'assignedTo'
    }

    def __init__(self, assigned_to_name=None, source=None, assigned_by=None, assigned_to_email=None, user_type=None, assigned_to=None):  # noqa: E501
        """JobDetailsAssigned - a model defined in Swagger"""  # noqa: E501
        self._assigned_to_name = None
        self._source = None
        self._assigned_by = None
        self._assigned_to_email = None
        self._user_type = None
        self._assigned_to = None
        self.discriminator = None
        if assigned_to_name is not None:
            self.assigned_to_name = assigned_to_name
        if source is not None:
            self.source = source
        if assigned_by is not None:
            self.assigned_by = assigned_by
        if assigned_to_email is not None:
            self.assigned_to_email = assigned_to_email
        if user_type is not None:
            self.user_type = user_type
        if assigned_to is not None:
            self.assigned_to = assigned_to

    @property
    def assigned_to_name(self):
        """Gets the assigned_to_name of this JobDetailsAssigned.  # noqa: E501

        Name of the user to whom the job is assigned.  # noqa: E501

        :return: The assigned_to_name of this JobDetailsAssigned.  # noqa: E501
        :rtype: str
        """
        return self._assigned_to_name

    @assigned_to_name.setter
    def assigned_to_name(self, assigned_to_name):
        """Sets the assigned_to_name of this JobDetailsAssigned.

        Name of the user to whom the job is assigned.  # noqa: E501

        :param assigned_to_name: The assigned_to_name of this JobDetailsAssigned.  # noqa: E501
        :type: str
        """

        self._assigned_to_name = assigned_to_name

    @property
    def source(self):
        """Gets the source of this JobDetailsAssigned.  # noqa: E501

        The source which which got assigned to the job.  # noqa: E501

        :return: The source of this JobDetailsAssigned.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobDetailsAssigned.

        The source which which got assigned to the job.  # noqa: E501

        :param source: The source of this JobDetailsAssigned.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def assigned_by(self):
        """Gets the assigned_by of this JobDetailsAssigned.  # noqa: E501

        Assigned by user number.  # noqa: E501

        :return: The assigned_by of this JobDetailsAssigned.  # noqa: E501
        :rtype: float
        """
        return self._assigned_by

    @assigned_by.setter
    def assigned_by(self, assigned_by):
        """Sets the assigned_by of this JobDetailsAssigned.

        Assigned by user number.  # noqa: E501

        :param assigned_by: The assigned_by of this JobDetailsAssigned.  # noqa: E501
        :type: float
        """

        self._assigned_by = assigned_by

    @property
    def assigned_to_email(self):
        """Gets the assigned_to_email of this JobDetailsAssigned.  # noqa: E501

        Assignee email address.  # noqa: E501

        :return: The assigned_to_email of this JobDetailsAssigned.  # noqa: E501
        :rtype: str
        """
        return self._assigned_to_email

    @assigned_to_email.setter
    def assigned_to_email(self, assigned_to_email):
        """Sets the assigned_to_email of this JobDetailsAssigned.

        Assignee email address.  # noqa: E501

        :param assigned_to_email: The assigned_to_email of this JobDetailsAssigned.  # noqa: E501
        :type: str
        """

        self._assigned_to_email = assigned_to_email

    @property
    def user_type(self):
        """Gets the user_type of this JobDetailsAssigned.  # noqa: E501

        Type of user.  # noqa: E501

        :return: The user_type of this JobDetailsAssigned.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this JobDetailsAssigned.

        Type of user.  # noqa: E501

        :param user_type: The user_type of this JobDetailsAssigned.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def assigned_to(self):
        """Gets the assigned_to of this JobDetailsAssigned.  # noqa: E501

        Assignee user name.  # noqa: E501

        :return: The assigned_to of this JobDetailsAssigned.  # noqa: E501
        :rtype: str
        """
        return self._assigned_to

    @assigned_to.setter
    def assigned_to(self, assigned_to):
        """Sets the assigned_to of this JobDetailsAssigned.

        Assignee user name.  # noqa: E501

        :param assigned_to: The assigned_to of this JobDetailsAssigned.  # noqa: E501
        :type: str
        """

        self._assigned_to = assigned_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsAssigned, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsAssigned):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SuccessResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'status_code': 'str',
        'status_message': 'str',
        'data': 'object'
    }

    attribute_map = {
        'status': 'status',
        'status_code': 'statusCode',
        'status_message': 'statusMessage',
        'data': 'data'
    }

    def __init__(self, status=None, status_code=None, status_message=None, data=None):  # noqa: E501
        """SuccessResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._status_code = None
        self._status_message = None
        self._data = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if status_code is not None:
            self.status_code = status_code
        if status_message is not None:
            self.status_message = status_message
        if data is not None:
            self.data = data

    @property
    def status(self):
        """Gets the status of this SuccessResponse.  # noqa: E501

        Status of the response.  # noqa: E501

        :return: The status of this SuccessResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SuccessResponse.

        Status of the response.  # noqa: E501

        :param status: The status of this SuccessResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_code(self):
        """Gets the status_code of this SuccessResponse.  # noqa: E501

        Status code of the response. This is to uniquely identify the status.  # noqa: E501

        :return: The status_code of this SuccessResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this SuccessResponse.

        Status code of the response. This is to uniquely identify the status.  # noqa: E501

        :param status_code: The status_code of this SuccessResponse.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def status_message(self):
        """Gets the status_message of this SuccessResponse.  # noqa: E501

        Status message of the response.  # noqa: E501

        :return: The status_message of this SuccessResponse.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """Sets the status_message of this SuccessResponse.

        Status message of the response.  # noqa: E501

        :param status_message: The status_message of this SuccessResponse.  # noqa: E501
        :type: str
        """

        self._status_message = status_message

    @property
    def data(self):
        """Gets the data of this SuccessResponse.  # noqa: E501


        :return: The data of this SuccessResponse.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this SuccessResponse.


        :param data: The data of this SuccessResponse.  # noqa: E501
        :type: object
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SuccessResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SuccessResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateWorkflowRequestStages(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status_code': 'str',
        'status_id': 'str',
        'is_rejection_stage': 'bool',
        'is_final_stage': 'bool',
        'further_transition_stages': 'list[CreateWorkflowRequestFurtherTransitionStages]'
    }

    attribute_map = {
        'name': 'name',
        'status_code': 'statusCode',
        'status_id': 'statusId',
        'is_rejection_stage': 'isRejectionStage',
        'is_final_stage': 'isFinalStage',
        'further_transition_stages': 'furtherTransitionStages'
    }

    def __init__(self, name=None, status_code=None, status_id=None, is_rejection_stage=None, is_final_stage=None, further_transition_stages=None):  # noqa: E501
        """CreateWorkflowRequestStages - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._status_code = None
        self._status_id = None
        self._is_rejection_stage = None
        self._is_final_stage = None
        self._further_transition_stages = None
        self.discriminator = None
        self.name = name
        self.status_code = status_code
        self.status_id = status_id
        self.is_rejection_stage = is_rejection_stage
        self.is_final_stage = is_final_stage
        if further_transition_stages is not None:
            self.further_transition_stages = further_transition_stages

    @property
    def name(self):
        """Gets the name of this CreateWorkflowRequestStages.  # noqa: E501

        Name of the workflow stage.  # noqa: E501

        :return: The name of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateWorkflowRequestStages.

        Name of the workflow stage.  # noqa: E501

        :param name: The name of this CreateWorkflowRequestStages.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this CreateWorkflowRequestStages.  # noqa: E501

        Status code associated with the workflow stage.  # noqa: E501

        :return: The status_code of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this CreateWorkflowRequestStages.

        Status code associated with the workflow stage.  # noqa: E501

        :param status_code: The status_code of this CreateWorkflowRequestStages.  # noqa: E501
        :type: str
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    @property
    def status_id(self):
        """Gets the status_id of this CreateWorkflowRequestStages.  # noqa: E501

        ID associated with the status of the workflow stage.  # noqa: E501

        :return: The status_id of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this CreateWorkflowRequestStages.

        ID associated with the status of the workflow stage.  # noqa: E501

        :param status_id: The status_id of this CreateWorkflowRequestStages.  # noqa: E501
        :type: str
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def is_rejection_stage(self):
        """Gets the is_rejection_stage of this CreateWorkflowRequestStages.  # noqa: E501

        Boolean indicating whether the stage is a rejection stage.  # noqa: E501

        :return: The is_rejection_stage of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejection_stage

    @is_rejection_stage.setter
    def is_rejection_stage(self, is_rejection_stage):
        """Sets the is_rejection_stage of this CreateWorkflowRequestStages.

        Boolean indicating whether the stage is a rejection stage.  # noqa: E501

        :param is_rejection_stage: The is_rejection_stage of this CreateWorkflowRequestStages.  # noqa: E501
        :type: bool
        """
        if is_rejection_stage is None:
            raise ValueError("Invalid value for `is_rejection_stage`, must not be `None`")  # noqa: E501

        self._is_rejection_stage = is_rejection_stage

    @property
    def is_final_stage(self):
        """Gets the is_final_stage of this CreateWorkflowRequestStages.  # noqa: E501

        Boolean indicating whether the stage is a final stage.  # noqa: E501

        :return: The is_final_stage of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: bool
        """
        return self._is_final_stage

    @is_final_stage.setter
    def is_final_stage(self, is_final_stage):
        """Sets the is_final_stage of this CreateWorkflowRequestStages.

        Boolean indicating whether the stage is a final stage.  # noqa: E501

        :param is_final_stage: The is_final_stage of this CreateWorkflowRequestStages.  # noqa: E501
        :type: bool
        """
        if is_final_stage is None:
            raise ValueError("Invalid value for `is_final_stage`, must not be `None`")  # noqa: E501

        self._is_final_stage = is_final_stage

    @property
    def further_transition_stages(self):
        """Gets the further_transition_stages of this CreateWorkflowRequestStages.  # noqa: E501

        Array of objects representing further transition stages.  # noqa: E501

        :return: The further_transition_stages of this CreateWorkflowRequestStages.  # noqa: E501
        :rtype: list[CreateWorkflowRequestFurtherTransitionStages]
        """
        return self._further_transition_stages

    @further_transition_stages.setter
    def further_transition_stages(self, further_transition_stages):
        """Sets the further_transition_stages of this CreateWorkflowRequestStages.

        Array of objects representing further transition stages.  # noqa: E501

        :param further_transition_stages: The further_transition_stages of this CreateWorkflowRequestStages.  # noqa: E501
        :type: list[CreateWorkflowRequestFurtherTransitionStages]
        """

        self._further_transition_stages = further_transition_stages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateWorkflowRequestStages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateWorkflowRequestStages):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobs-questionnarie-api

    These APIs streamline question management, providing tools to create, delete, and update questions. Additionally, they offer functionality to attach question lists to specific job profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateQuestionnarieTemplatesRequestPreScreeningQuestions(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'question': 'str',
        'options': 'list[CreateJobQuestionnarieRequestOptions]',
        'type': 'str',
        'knockoff_type': 'bool',
        'knockoff_message': 'str',
        'qualified_answer': 'str'
    }

    attribute_map = {
        'question': 'question',
        'options': 'options',
        'type': 'type',
        'knockoff_type': 'knockoffType',
        'knockoff_message': 'knockoffMessage',
        'qualified_answer': 'qualifiedAnswer'
    }

    def __init__(self, question=None, options=None, type=None, knockoff_type=None, knockoff_message=None, qualified_answer=None):  # noqa: E501
        """CreateQuestionnarieTemplatesRequestPreScreeningQuestions - a model defined in Swagger"""  # noqa: E501
        self._question = None
        self._options = None
        self._type = None
        self._knockoff_type = None
        self._knockoff_message = None
        self._qualified_answer = None
        self.discriminator = None
        self.question = question
        self.options = options
        self.type = type
        self.knockoff_type = knockoff_type
        self.knockoff_message = knockoff_message
        if qualified_answer is not None:
            self.qualified_answer = qualified_answer

    @property
    def question(self):
        """Gets the question of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501

        The text of the pre screening question.  # noqa: E501

        :return: The question of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: str
        """
        return self._question

    @question.setter
    def question(self, question):
        """Sets the question of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.

        The text of the pre screening question.  # noqa: E501

        :param question: The question of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: str
        """
        if question is None:
            raise ValueError("Invalid value for `question`, must not be `None`")  # noqa: E501

        self._question = question

    @property
    def options(self):
        """Gets the options of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501


        :return: The options of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: list[CreateJobQuestionnarieRequestOptions]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.


        :param options: The options of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: list[CreateJobQuestionnarieRequestOptions]
        """
        if options is None:
            raise ValueError("Invalid value for `options`, must not be `None`")  # noqa: E501

        self._options = options

    @property
    def type(self):
        """Gets the type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501

        The type of the question.  # noqa: E501

        :return: The type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.

        The type of the question.  # noqa: E501

        :param type: The type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def knockoff_type(self):
        """Gets the knockoff_type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501

        A boolean indicating if the question has a knockoff.  # noqa: E501

        :return: The knockoff_type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: bool
        """
        return self._knockoff_type

    @knockoff_type.setter
    def knockoff_type(self, knockoff_type):
        """Sets the knockoff_type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.

        A boolean indicating if the question has a knockoff.  # noqa: E501

        :param knockoff_type: The knockoff_type of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: bool
        """
        if knockoff_type is None:
            raise ValueError("Invalid value for `knockoff_type`, must not be `None`")  # noqa: E501

        self._knockoff_type = knockoff_type

    @property
    def knockoff_message(self):
        """Gets the knockoff_message of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501

        The knockoff message associated with the question.  # noqa: E501

        :return: The knockoff_message of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: str
        """
        return self._knockoff_message

    @knockoff_message.setter
    def knockoff_message(self, knockoff_message):
        """Sets the knockoff_message of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.

        The knockoff message associated with the question.  # noqa: E501

        :param knockoff_message: The knockoff_message of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: str
        """
        if knockoff_message is None:
            raise ValueError("Invalid value for `knockoff_message`, must not be `None`")  # noqa: E501

        self._knockoff_message = knockoff_message

    @property
    def qualified_answer(self):
        """Gets the qualified_answer of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501

        The qualified answer for the question.  # noqa: E501

        :return: The qualified_answer of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :rtype: str
        """
        return self._qualified_answer

    @qualified_answer.setter
    def qualified_answer(self, qualified_answer):
        """Sets the qualified_answer of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.

        The qualified answer for the question.  # noqa: E501

        :param qualified_answer: The qualified_answer of this CreateQuestionnarieTemplatesRequestPreScreeningQuestions.  # noqa: E501
        :type: str
        """

        self._qualified_answer = qualified_answer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateQuestionnarieTemplatesRequestPreScreeningQuestions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateQuestionnarieTemplatesRequestPreScreeningQuestions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    employees-api

    The employee profile APIs are used to create, access, update and delete employee profile and preferences.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeeProfile(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'employee_id': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'designation': 'str',
        'location': 'str',
        'picture_url': 'str'
    }

    attribute_map = {
        'employee_id': 'employeeId',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'designation': 'designation',
        'location': 'location',
        'picture_url': 'pictureUrl'
    }

    def __init__(self, employee_id='1002345', first_name='John', last_name='Doe', email='test.email@example.com', designation='Software Developer', location='Princeton,New Jersey,USA', picture_url='https://assets.client.com/CareerConnectResources/pp/CLIENTID/wallpaper_preview.jpg'):  # noqa: E501
        """EmployeeProfile - a model defined in Swagger"""  # noqa: E501
        self._employee_id = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._designation = None
        self._location = None
        self._picture_url = None
        self.discriminator = None
        if employee_id is not None:
            self.employee_id = employee_id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if designation is not None:
            self.designation = designation
        if location is not None:
            self.location = location
        if picture_url is not None:
            self.picture_url = picture_url

    @property
    def employee_id(self):
        """Gets the employee_id of this EmployeeProfile.  # noqa: E501

        Employee Id - unique field to identify the employee.  # noqa: E501

        :return: The employee_id of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this EmployeeProfile.

        Employee Id - unique field to identify the employee.  # noqa: E501

        :param employee_id: The employee_id of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def first_name(self):
        """Gets the first_name of this EmployeeProfile.  # noqa: E501

        First name of the employee.  # noqa: E501

        :return: The first_name of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this EmployeeProfile.

        First name of the employee.  # noqa: E501

        :param first_name: The first_name of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this EmployeeProfile.  # noqa: E501

        Last name of the employee.  # noqa: E501

        :return: The last_name of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this EmployeeProfile.

        Last name of the employee.  # noqa: E501

        :param last_name: The last_name of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this EmployeeProfile.  # noqa: E501

        Company email of the employee.  # noqa: E501

        :return: The email of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmployeeProfile.

        Company email of the employee.  # noqa: E501

        :param email: The email of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def designation(self):
        """Gets the designation of this EmployeeProfile.  # noqa: E501

        Designation of the employee in the company.  # noqa: E501

        :return: The designation of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._designation

    @designation.setter
    def designation(self, designation):
        """Sets the designation of this EmployeeProfile.

        Designation of the employee in the company.  # noqa: E501

        :param designation: The designation of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._designation = designation

    @property
    def location(self):
        """Gets the location of this EmployeeProfile.  # noqa: E501

        Location of the employee.  # noqa: E501

        :return: The location of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this EmployeeProfile.

        Location of the employee.  # noqa: E501

        :param location: The location of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def picture_url(self):
        """Gets the picture_url of this EmployeeProfile.  # noqa: E501

        Picture of the employee.  # noqa: E501

        :return: The picture_url of this EmployeeProfile.  # noqa: E501
        :rtype: str
        """
        return self._picture_url

    @picture_url.setter
    def picture_url(self, picture_url):
        """Sets the picture_url of this EmployeeProfile.

        Picture of the employee.  # noqa: E501

        :param picture_url: The picture_url of this EmployeeProfile.  # noqa: E501
        :type: str
        """

        self._picture_url = picture_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeeProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeeProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ContactData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'country_phone_code': 'str',
        'phone_number': 'str',
        'device_type': 'str',
        'phone_extension': 'str',
        'email': 'str'
    }

    attribute_map = {
        'country_phone_code': 'countryPhoneCode',
        'phone_number': 'phoneNumber',
        'device_type': 'deviceType',
        'phone_extension': 'phoneExtension',
        'email': 'email'
    }

    def __init__(self, country_phone_code=None, phone_number=None, device_type=None, phone_extension=None, email=None):  # noqa: E501
        """ContactData - a model defined in Swagger"""  # noqa: E501
        self._country_phone_code = None
        self._phone_number = None
        self._device_type = None
        self._phone_extension = None
        self._email = None
        self.discriminator = None
        if country_phone_code is not None:
            self.country_phone_code = country_phone_code
        if phone_number is not None:
            self.phone_number = phone_number
        if device_type is not None:
            self.device_type = device_type
        if phone_extension is not None:
            self.phone_extension = phone_extension
        self.email = email

    @property
    def country_phone_code(self):
        """Gets the country_phone_code of this ContactData.  # noqa: E501

        Country Phone Code.  # noqa: E501

        :return: The country_phone_code of this ContactData.  # noqa: E501
        :rtype: str
        """
        return self._country_phone_code

    @country_phone_code.setter
    def country_phone_code(self, country_phone_code):
        """Sets the country_phone_code of this ContactData.

        Country Phone Code.  # noqa: E501

        :param country_phone_code: The country_phone_code of this ContactData.  # noqa: E501
        :type: str
        """

        self._country_phone_code = country_phone_code

    @property
    def phone_number(self):
        """Gets the phone_number of this ContactData.  # noqa: E501

        Phone Number.  # noqa: E501

        :return: The phone_number of this ContactData.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ContactData.

        Phone Number.  # noqa: E501

        :param phone_number: The phone_number of this ContactData.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def device_type(self):
        """Gets the device_type of this ContactData.  # noqa: E501

        Device Type. Eg: Mobile, Landline, etc.  # noqa: E501

        :return: The device_type of this ContactData.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this ContactData.

        Device Type. Eg: Mobile, Landline, etc.  # noqa: E501

        :param device_type: The device_type of this ContactData.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def phone_extension(self):
        """Gets the phone_extension of this ContactData.  # noqa: E501

        Phone Extension. Eg: 1234, etc.  # noqa: E501

        :return: The phone_extension of this ContactData.  # noqa: E501
        :rtype: str
        """
        return self._phone_extension

    @phone_extension.setter
    def phone_extension(self, phone_extension):
        """Sets the phone_extension of this ContactData.

        Phone Extension. Eg: 1234, etc.  # noqa: E501

        :param phone_extension: The phone_extension of this ContactData.  # noqa: E501
        :type: str
        """

        self._phone_extension = phone_extension

    @property
    def email(self):
        """Gets the email of this ContactData.  # noqa: E501

        Email Address.  # noqa: E501

        :return: The email of this ContactData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ContactData.

        Email Address.  # noqa: E501

        :param email: The email of this ContactData.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContactData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class CandidatesAttachmentsApi(object):
    base_path = "/candidates-api/applications"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def get_candidate_job_id_specific_attachments(self, candidate_id, job_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Attachments for candidate based on JobId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_job_id_specific_attachments(candidate_id, job_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str job_id: Id of the job (required)
        :param str x_ph_user_id: (required)
        :param str application_id:
        :return: Attachment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_candidate_job_id_specific_attachments_with_http_info(candidate_id, job_id, x_ph_user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_candidate_job_id_specific_attachments_with_http_info(candidate_id, job_id, x_ph_user_id, **kwargs)  # noqa: E501
            return data

    def get_candidate_job_id_specific_attachments_with_http_info(self, candidate_id, job_id, x_ph_user_id, **kwargs):  # noqa: E501
        """Get Attachments for candidate based on JobId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_candidate_job_id_specific_attachments_with_http_info(candidate_id, job_id, x_ph_user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str candidate_id: Id of the candidate (required)
        :param str job_id: Id of the job (required)
        :param str x_ph_user_id: (required)
        :param str application_id:
        :return: Attachment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['candidate_id', 'job_id', 'x_ph_user_id', 'application_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_candidate_job_id_specific_attachments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `get_candidate_job_id_specific_attachments`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `get_candidate_job_id_specific_attachments`")  # noqa: E501
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `get_candidate_job_id_specific_attachments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []
        if 'application_id' in params:
            query_params.append(('applicationId', params['application_id']))  # noqa: E501

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/jobs/{jobId}/attachments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Attachment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    employees-api-referral

    The employee referral APIs are used to refer, track and recommend jobs to external candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class EmployeeReferralsApi(object):
    base_path = "/employees-api/referral"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_employee_referral(self, body, employee_id, **kwargs):  # noqa: E501
        """Employee Referral  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_employee_referral(body, employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateEmployeeReferral body: (required)
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: ReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_employee_referral_with_http_info(body, employee_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_employee_referral_with_http_info(body, employee_id, **kwargs)  # noqa: E501
            return data

    def create_employee_referral_with_http_info(self, body, employee_id, **kwargs):  # noqa: E501
        """Employee Referral  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_employee_referral_with_http_info(body, employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateEmployeeReferral body: (required)
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: ReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'employee_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_employee_referral" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_employee_referral`")  # noqa: E501
        # verify the required parameter 'employee_id' is set
        if ('employee_id' not in params or
                params['employee_id'] is None):
            raise ValueError("Missing the required parameter `employee_id` when calling `create_employee_referral`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'employee_id' in params:
            path_params['employeeId'] = params['employee_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/employees/{employeeId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReferralSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_employee_referral_questionnaire(self, body, **kwargs):  # noqa: E501
        """Create Referral Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_employee_referral_questionnaire(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateEmployeeReferralQuestionnaire body: (required)
        :return: ReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_employee_referral_questionnaire_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_employee_referral_questionnaire_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_employee_referral_questionnaire_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create Referral Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_employee_referral_questionnaire_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateEmployeeReferralQuestionnaire body: (required)
        :return: ReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_employee_referral_questionnaire" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_employee_referral_questionnaire`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReferralSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_employee_referral_questionnaire(self, **kwargs):  # noqa: E501
        """Get Referral Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_employee_referral_questionnaire(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetReferralQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_employee_referral_questionnaire_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_employee_referral_questionnaire_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_employee_referral_questionnaire_with_http_info(self, **kwargs):  # noqa: E501
        """Get Referral Questionnaire  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_employee_referral_questionnaire_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: GetReferralQuestionnaireResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_employee_referral_questionnaire" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/questionnaire', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetReferralQuestionnaireResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_employee_referrals(self, employee_id, **kwargs):  # noqa: E501
        """Get Referrals  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_employee_referrals(employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: GetEmployeeReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_employee_referrals_with_http_info(employee_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_employee_referrals_with_http_info(employee_id, **kwargs)  # noqa: E501
            return data

    def get_employee_referrals_with_http_info(self, employee_id, **kwargs):  # noqa: E501
        """Get Referrals  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_employee_referrals_with_http_info(employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: GetEmployeeReferralSuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['employee_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_employee_referrals" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'employee_id' is set
        if ('employee_id' not in params or
                params['employee_id'] is None):
            raise ValueError("Missing the required parameter `employee_id` when calling `get_employee_referrals`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'employee_id' in params:
            path_params['employeeId'] = params['employee_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/employees/{employeeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEmployeeReferralSuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_referral_recommendations(self, employee_id, **kwargs):  # noqa: E501
        """Get Job Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_referral_recommendations(employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: GetReferralRecommendationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_referral_recommendations_with_http_info(employee_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_referral_recommendations_with_http_info(employee_id, **kwargs)  # noqa: E501
            return data

    def get_referral_recommendations_with_http_info(self, employee_id, **kwargs):  # noqa: E501
        """Get Job Recommendations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_referral_recommendations_with_http_info(employee_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str employee_id: Employee Id - unique field to identify the employee. (required)
        :return: GetReferralRecommendationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['employee_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_referral_recommendations" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'employee_id' is set
        if ('employee_id' not in params or
                params['employee_id'] is None):
            raise ValueError("Missing the required parameter `employee_id` when calling `get_referral_recommendations`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'employee_id' in params:
            path_params['employeeId'] = params['employee_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/employees/{employeeId}/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetReferralRecommendationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_referral_recommendations_with_resume(self, body, **kwargs):  # noqa: E501
        """Get Job Recommendations With Resume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_referral_recommendations_with_resume(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetReferralRecommendationsWithResume body: (required)
        :return: GetReferralRecommendationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_referral_recommendations_with_resume_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.get_referral_recommendations_with_resume_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def get_referral_recommendations_with_resume_with_http_info(self, body, **kwargs):  # noqa: E501
        """Get Job Recommendations With Resume  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_referral_recommendations_with_resume_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetReferralRecommendationsWithResume body: (required)
        :return: GetReferralRecommendationsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_referral_recommendations_with_resume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `get_referral_recommendations_with_resume`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/employees/jobs/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetReferralRecommendationsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AddNotes(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'note_type': 'str',
        'note_text': 'str',
        'as_private': 'bool',
        'job_id': 'str',
        'tagged_recruiters': 'object'
    }

    attribute_map = {
        'note_type': 'noteType',
        'note_text': 'noteText',
        'as_private': 'asPrivate',
        'job_id': 'jobId',
        'tagged_recruiters': 'taggedRecruiters'
    }

    def __init__(self, note_type=None, note_text=None, as_private=None, job_id=None, tagged_recruiters=None):  # noqa: E501
        """AddNotes - a model defined in Swagger"""  # noqa: E501
        self._note_type = None
        self._note_text = None
        self._as_private = None
        self._job_id = None
        self._tagged_recruiters = None
        self.discriminator = None
        if note_type is not None:
            self.note_type = note_type
        if note_text is not None:
            self.note_text = note_text
        if as_private is not None:
            self.as_private = as_private
        if job_id is not None:
            self.job_id = job_id
        if tagged_recruiters is not None:
            self.tagged_recruiters = tagged_recruiters

    @property
    def note_type(self):
        """Gets the note_type of this AddNotes.  # noqa: E501

        The type of the note that is being created. This field specifies the category of the note.  # noqa: E501

        :return: The note_type of this AddNotes.  # noqa: E501
        :rtype: str
        """
        return self._note_type

    @note_type.setter
    def note_type(self, note_type):
        """Sets the note_type of this AddNotes.

        The type of the note that is being created. This field specifies the category of the note.  # noqa: E501

        :param note_type: The note_type of this AddNotes.  # noqa: E501
        :type: str
        """

        self._note_type = note_type

    @property
    def note_text(self):
        """Gets the note_text of this AddNotes.  # noqa: E501

        The text content of the note. This field holds the actual content or information of the note.  # noqa: E501

        :return: The note_text of this AddNotes.  # noqa: E501
        :rtype: str
        """
        return self._note_text

    @note_text.setter
    def note_text(self, note_text):
        """Sets the note_text of this AddNotes.

        The text content of the note. This field holds the actual content or information of the note.  # noqa: E501

        :param note_text: The note_text of this AddNotes.  # noqa: E501
        :type: str
        """

        self._note_text = note_text

    @property
    def as_private(self):
        """Gets the as_private of this AddNotes.  # noqa: E501

        A boolean flag indicating whether the note is private or not. If true, the note is intended to be visible only to individuals who created it.  # noqa: E501

        :return: The as_private of this AddNotes.  # noqa: E501
        :rtype: bool
        """
        return self._as_private

    @as_private.setter
    def as_private(self, as_private):
        """Sets the as_private of this AddNotes.

        A boolean flag indicating whether the note is private or not. If true, the note is intended to be visible only to individuals who created it.  # noqa: E501

        :param as_private: The as_private of this AddNotes.  # noqa: E501
        :type: bool
        """

        self._as_private = as_private

    @property
    def job_id(self):
        """Gets the job_id of this AddNotes.  # noqa: E501

        The unique identifier (ID) associated with the job related to the note. This field links the note to a specific job or task.  # noqa: E501

        :return: The job_id of this AddNotes.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this AddNotes.

        The unique identifier (ID) associated with the job related to the note. This field links the note to a specific job or task.  # noqa: E501

        :param job_id: The job_id of this AddNotes.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def tagged_recruiters(self):
        """Gets the tagged_recruiters of this AddNotes.  # noqa: E501

        An object containing ids about recruiters tagged in the note.  # noqa: E501

        :return: The tagged_recruiters of this AddNotes.  # noqa: E501
        :rtype: object
        """
        return self._tagged_recruiters

    @tagged_recruiters.setter
    def tagged_recruiters(self, tagged_recruiters):
        """Sets the tagged_recruiters of this AddNotes.

        An object containing ids about recruiters tagged in the note.  # noqa: E501

        :param tagged_recruiters: The tagged_recruiters of this AddNotes.  # noqa: E501
        :type: object
        """

        self._tagged_recruiters = tagged_recruiters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddNotes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddNotes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    search-api

    These APIs helps to search and suggest based on keyword among available jobs.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class LocationData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latlong': 'str',
        'location': 'str',
        'radius': 'int',
        'radius_unit': 'str'
    }

    attribute_map = {
        'latlong': 'latlong',
        'location': 'location',
        'radius': 'radius',
        'radius_unit': 'radiusUnit'
    }

    def __init__(self, latlong=None, location=None, radius=None, radius_unit=None):  # noqa: E501
        """LocationData - a model defined in Swagger"""  # noqa: E501
        self._latlong = None
        self._location = None
        self._radius = None
        self._radius_unit = None
        self.discriminator = None
        if latlong is not None:
            self.latlong = latlong
        if location is not None:
            self.location = location
        if radius is not None:
            self.radius = radius
        if radius_unit is not None:
            self.radius_unit = radius_unit

    @property
    def latlong(self):
        """Gets the latlong of this LocationData.  # noqa: E501

        Latitude, Longitude of the location.  # noqa: E501

        :return: The latlong of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._latlong

    @latlong.setter
    def latlong(self, latlong):
        """Sets the latlong of this LocationData.

        Latitude, Longitude of the location.  # noqa: E501

        :param latlong: The latlong of this LocationData.  # noqa: E501
        :type: str
        """

        self._latlong = latlong

    @property
    def location(self):
        """Gets the location of this LocationData.  # noqa: E501

        Location Value.  # noqa: E501

        :return: The location of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this LocationData.

        Location Value.  # noqa: E501

        :param location: The location of this LocationData.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def radius(self):
        """Gets the radius of this LocationData.  # noqa: E501

        Radius to consider from the entered location.  # noqa: E501

        :return: The radius of this LocationData.  # noqa: E501
        :rtype: int
        """
        return self._radius

    @radius.setter
    def radius(self, radius):
        """Sets the radius of this LocationData.

        Radius to consider from the entered location.  # noqa: E501

        :param radius: The radius of this LocationData.  # noqa: E501
        :type: int
        """

        self._radius = radius

    @property
    def radius_unit(self):
        """Gets the radius_unit of this LocationData.  # noqa: E501

        Radius unit to consider.  # noqa: E501

        :return: The radius_unit of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._radius_unit

    @radius_unit.setter
    def radius_unit(self, radius_unit):
        """Sets the radius_unit of this LocationData.

        Radius unit to consider.  # noqa: E501

        :param radius_unit: The radius_unit of this LocationData.  # noqa: E501
        :type: str
        """

        self._radius_unit = radius_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ExperienceData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_name': 'str',
        'title': 'str',
        'location': 'str',
        'description': 'str',
        'from_to': 'FromTo'
    }

    attribute_map = {
        'company_name': 'companyName',
        'title': 'title',
        'location': 'location',
        'description': 'description',
        'from_to': 'fromTo'
    }

    def __init__(self, company_name=None, title=None, location=None, description=None, from_to=None):  # noqa: E501
        """ExperienceData - a model defined in Swagger"""  # noqa: E501
        self._company_name = None
        self._title = None
        self._location = None
        self._description = None
        self._from_to = None
        self.discriminator = None
        self.company_name = company_name
        self.title = title
        if location is not None:
            self.location = location
        if description is not None:
            self.description = description
        if from_to is not None:
            self.from_to = from_to

    @property
    def company_name(self):
        """Gets the company_name of this ExperienceData.  # noqa: E501

        Name of the Company.  # noqa: E501

        :return: The company_name of this ExperienceData.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this ExperienceData.

        Name of the Company.  # noqa: E501

        :param company_name: The company_name of this ExperienceData.  # noqa: E501
        :type: str
        """
        if company_name is None:
            raise ValueError("Invalid value for `company_name`, must not be `None`")  # noqa: E501

        self._company_name = company_name

    @property
    def title(self):
        """Gets the title of this ExperienceData.  # noqa: E501

        Title of the experience.  # noqa: E501

        :return: The title of this ExperienceData.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ExperienceData.

        Title of the experience.  # noqa: E501

        :param title: The title of this ExperienceData.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def location(self):
        """Gets the location of this ExperienceData.  # noqa: E501

        Location of the experience.  # noqa: E501

        :return: The location of this ExperienceData.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ExperienceData.

        Location of the experience.  # noqa: E501

        :param location: The location of this ExperienceData.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def description(self):
        """Gets the description of this ExperienceData.  # noqa: E501

        Description of the experience.  # noqa: E501

        :return: The description of this ExperienceData.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ExperienceData.

        Description of the experience.  # noqa: E501

        :param description: The description of this ExperienceData.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def from_to(self):
        """Gets the from_to of this ExperienceData.  # noqa: E501


        :return: The from_to of this ExperienceData.  # noqa: E501
        :rtype: FromTo
        """
        return self._from_to

    @from_to.setter
    def from_to(self, from_to):
        """Sets the from_to of this ExperienceData.


        :param from_to: The from_to of this ExperienceData.  # noqa: E501
        :type: FromTo
        """

        self._from_to = from_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExperienceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExperienceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
